@@ -82,7 +82,7 @@ class CfgNode(dict):
             value = cls(init_dict=value, copy=False)
         elif isinstance(value, str):
             try:
-                literal_eval(value)
+                value = literal_eval(value)
             except(ValueError, SyntaxError):
                 pass
         return value
@@ -156,7 +156,13 @@ class CfgNode(dict):
 
         cfg = cfg.copy()
         for key, value in cfg.items():
-            self[key] = value
+            if key not in self:
+                self[key] = value
+            elif self[key] != value:
+                if isinstance(self[key], CfgNode) and isinstance(value, CfgNode):
+                    self[key].merge(value)
+                else:
+                    self[key] = value
 
 
     def save(self, save_path, encoding='utf-8'):
@@ -278,3 +284,19 @@ class CfgNode(dict):
         """
         cfg_dict = CfgNode._convert_cfg_to_dict(cfg)
         return yaml.safe_dump(cfg_dict, stream=stream, encoding=encoding, **kwargs)
+
+    def dict(self):
+        """
+        convert to a dict
+
+        Returns:
+            dict:
+        """
+        return CfgNode._convert_cfg_to_dict(self)
+
+    def __str__(self):
+        """
+        Returns:
+            str: a str of dict format
+        """
+        return str(self.dict())
